==> skytemple_files-1.6.6-py3-none-any.whl: skytemple_files/compression/generic_nrl/handler.py <==
#  Copyright 2020-2024 Capypara and the SkyTemple Contributors
#
#  This file is part of SkyTemple.
#
#  SkyTemple is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  SkyTemple is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with SkyTemple.  If not, see <https://www.gnu.org/licenses/>.

from __future__ import annotations


from skytemple_files.compression.generic_nrl.compressor import GenericNrlCompressor
from skytemple_files.compression.generic_nrl.decompressor import GenericNrlDecompressor


class GenericNrlHandler:
    """
    Generic version of the NRL compression algorithm. Uses 1 byte as input and output sizes.
    todo
    """

    @classmethod
    def decompress(
        cls, compressed_data: bytes, stop_when_size: int
    ) -> tuple[bytes, int]:
        """todo. Stops when stop_when_size bytes have been decompressed.
        Second return is compressed original size.
        """
        return GenericNrlDecompressor(compressed_data, stop_when_size).decompress()

    @classmethod
    def compress(cls, uncompressed_data: bytes) -> bytes:
        """todo"""
        return GenericNrlCompressor(uncompressed_data).compress()

==> skytemple_files-1.8.1-py3-none-any.whl: skytemple_files/compression/generic_nrl/handler.py <==
#  Copyright 2020-2024 Capypara and the SkyTemple Contributors
#
#  This file is part of SkyTemple.
#
#  SkyTemple is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  SkyTemple is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with SkyTemple.  If not, see <https://www.gnu.org/licenses/>.

from __future__ import annotations


from skytemple_files.compression.generic_nrl.compressor import GenericNrlCompressor
from skytemple_files.compression.generic_nrl.decompressor import GenericNrlDecompressor


class GenericNrlHandler:
    """
    Generic version of the NRL compression algorithm. Uses 1 byte as input and output sizes.
    todo
    """

    @classmethod
    def decompress(cls, compressed_data: bytes, stop_when_size: int) -> tuple[bytes, int]:
        """todo. Stops when stop_when_size bytes have been decompressed.
        Second return is compressed original size.
        """
        return GenericNrlDecompressor(compressed_data, stop_when_size).decompress()

    @classmethod
    def compress(cls, uncompressed_data: bytes) -> bytes:
        """todo"""
        return GenericNrlCompressor(uncompressed_data).compress()
